@@ -19,11 +19,16 @@ Dancer::Plugin::Interchange6 - Interchange6 Shop Plugin for Dancer
 
 =head1 VERSION
 
-Version 0.120
+Version 0.121
 
 =cut
 
-our $VERSION = '0.120';
+our $VERSION = '0.121';
+
+=head1 DESCRIPTION
+
+This L<Dancer> plugin is now DEPRECATED since all new development has moved
+to the L<Dancer2> plugin L<Dancer2::Plugin::Interchange6>.
 
 =head1 REQUIREMENTS
 
@@ -458,6 +463,8 @@ See http://dev.perl.org/licenses/ for more information.
 
 =head1 SEE ALSO
 
+L<Dancer2::Plugin::Interchange6>
+
 L<Interchange6>, L<Interchange6::Schema>
 
 =cut
