@@ -6,6 +6,7 @@ use Dancer::Plugin::Interchange6;
 use Dancer::Plugin::Interchange6::Routes::Account;
 use Dancer::Plugin::Interchange6::Routes::Cart;
 use Dancer::Plugin::Interchange6::Routes::Checkout;
+use Dancer::Plugin::Auth::Extensible;
 
 =head1 NAME
 
@@ -181,6 +182,21 @@ Disable parts of layout on the login view:
 
 =cut
 
+=head1 DANCER HOOKS
+
+The following standard L<Dancer> hooks are used:
+
+=head2 before
+
+Set L<Interchange6::Schema/current_user> for the default schema
+to L<Dancer::Plugin::Auth::Extensible/logged_in_user> or C<undef>.
+
+=cut
+
+hook before => sub {
+    shop_schema->set_current_user( logged_in_user || undef );
+};
+
 register shop_setup_routes => sub {
     _setup_routes();
 };
@@ -260,43 +276,37 @@ sub _setup_routes {
         my $path = captures->{'path'};
 
         # check for a matching product by uri
-        my $product = shop_product->find({uri => $path});
+        my $product = shop_product->single( { uri => $path, active => 1 } );
 
-        if (!defined $product) {
+        if (!$product) {
 
             # check for a matching product by sku
-            $product = shop_product($path);
+            $product = shop_product->single( { sku => $path, active => 1 } );
 
-            if ($product) {
-                if ($product->uri
-                    && $product->uri ne $path) {
-                    # permanent redirect to specific URL
-                    debug "Redirecting permanently to product uri ", $product->uri,
-                        " for $path.";
-                    return redirect(uri_for($product->uri), 301);
-                }
+            if ( $product && $product->uri ) {
+
+                # permanent redirect to specific URL
+                debug "Redirecting permanently to product uri ",
+                  $product->uri,
+                  " for $path.";
+                return redirect( uri_for( $product->uri ), 301 );
             }
         }
 
         if ($product) {
-            if ($product->active) {
-                # flypage
-                my $tokens = {product => $product};
 
-                execute_hook('before_product_display', $tokens);
+            # flypage
+            my $tokens = { product => $product };
 
-                my $output = template $routes_config->{product}->{template}, $tokens;
+            execute_hook( 'before_product_display', $tokens );
 
-                # temporary way to erase cart errors from missing variants
-                session shop_cart_error => undef;
+            my $output = template $routes_config->{product}->{template},
+              $tokens;
 
-                return $output;
-            }
-            else {
-                # discontinued
-                status 'not_found';
-                forward 404; 
-            }
+            # temporary way to erase cart errors from missing variants
+            session shop_cart_error => undef;
+
+            return $output;
         }
 
         # check for page number
@@ -310,7 +320,7 @@ sub _setup_routes {
         }
 
         # first check for navigation item
-        my $nav = shop_navigation->find({uri => $path});
+        my $nav = shop_navigation->single( { uri => $path, active => 1 } );
 
         if (defined $nav) {
 
@@ -340,7 +350,7 @@ sub _setup_routes {
               ->navigation_products
               ->search_related('product')
               ->active
-              ->listing( { users_id => session('logged_in_user_id') } )
+              ->listing
               ->order_by('!me.priority,!product.priority');
 
             if ( defined $routes_config->{navigation}->{records} ) {
@@ -399,9 +409,6 @@ sub _config_routes {
             # recurse
             _config_routes($settings->{$key}, $defaults->{$key});
         }
-        elsif (! exists $defaults->{$key}) {
-            die "Invalid entry in routes configuration: $key.";
-        }
         else {
             $settings->{$key} = $defaults->{$key};
         }
@@ -414,7 +421,7 @@ sub _config_warnings {
     my ($settings) = @_;
 
     if ($settings->{navigation}->{records} == 0) {
-        warn __PACKAGE__, ": Maximum number of navigation records is zero.\n";
+        warning __PACKAGE__, ": Maximum number of navigation records is zero.\n";
     }
 }
 
